Class: RDvdSlideshow::SlideshowTask
- Inherits:
-
RProgram::Task
- Object
- RProgram::Task
- RDvdSlideshow::SlideshowTask
- Defined in:
- lib/rdvd-slideshow/slideshow_task.rb
Overview
==dvd-slideshow options:
- -n
mencoder.name
- -o
mencoder.output_dir
- -b
mencoder.background
- -a
mencoder.audio_file
- -p
mencoder.pal
- -mp2
mencoder.mp2
- -L
mencoder.low_quality
- -H
mencoder.high_quality
- -theme
mencoder.theme
- -border
mencoder.border
- -sharpen
mencoder.sharpen
- -r
mencoder.auto_crop
- -w
mencoder.widescreen
- -smp
mencoder.smp
- -mpeg2enc
mencoder.mpeg2enc
- -vcd
mencoder.vcd
- -flv
mencoder.flv
- -s
mencoder.output_size
- -f
mencoder.input_file
Instead of providing an input file it is possible to programatically define the input with the write_input method
Instance Method Summary collapse
-
#write_input(&block) ⇒ Object
Configures the input configuration of the slideshow and generates automatically the corresponding input file.
Instance Method Details
#write_input(&block) ⇒ Object
Configures the input configuration of the slideshow and generates automatically the corresponding input file. The provided block is used to configure the SlideshowInput object
58 59 60 61 62 63 |
# File 'lib/rdvd-slideshow/slideshow_task.rb', line 58 def write_input(&block) @input = SlideshowInput.new do |input| block.call(input) if block end @options[:input_file] = @input.file_path end |